##
##  aria2.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2023 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         aria2
Summary:      Segmented File Downloading Tool
URL:          https://aria2.github.io/
Vendor:       Tatsuhiro Tsujikawa, Ross Smith II
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        PLUS
Group:        Web
License:      GPL
Version:      1.37.0
Release:      20231115

#   list of sources
Source0:      https://github.com/tatsuhiro-t/aria2/releases/download/release-%{version}/aria2-%{version}.tar.xz
Patch0:       aria2.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, gcc, gcc::with_cxx = yes
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  openssl, libxml, ares
PreReq:       openssl, libxml, ares

%description
    aria2(1) is a download utility with resuming and segmented
    downloading. Supported protocols are HTTP/HTTPS/FTP/BitTorrent. It
    also supports Metalink version 3.0 and chunk checksum in Metalink by
    validating chunk checksums while downloading a file.

%track
    prog aria2 = {
        version   = %{version}
        url       = https://github.com/tatsuhiro-t/aria2/releases
        regex     = tree/release-(\d(\.\d+)+)
    }

%prep
    %setup -q -n aria2-%{version}
    %patch -p0

%build
    CC="%{l_cc}" \
    CXX="%{l_cxx}" \
    CFLAGS="%{l_cflags}" \
    CXXFLAGS="%{l_cxxflags}" \
    CPPFLAGS="%{l_cppflags}" \
    LDFLAGS="%{l_ldflags}" \
    LIBS="-lstdc++" \
    ./configure \
        --prefix=%{l_prefix} \
        --mandir=%{l_prefix}/man \
        --with-openssl \
        --with-openssl-prefix=%{l_prefix} \
        --without-gnutls \
        --without-libuv \
        --with-libxml2 \
        --with-xml-prefix=%{l_prefix} \
        --with-libcares \
        --with-libcares-prefix=%{l_prefix} \
        --without-libiconv-prefix \
        --with-included-gettext \
        --without-libintl-prefix \
        --disable-nls
    %{l_make} %{l_mflags -O}

%install
    %{l_make} %{l_mflags} install AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/share/doc
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/man/ru
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/man/pt
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

